<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AllFields</name>
    <message>
        <location filename="../details.cpp" line="698"/>
        <source>Field</source>
        <translation>Feld</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="698"/>
        <source>Field name</source>
        <translation>Feldname</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="699"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="699"/>
        <source>Field description</source>
        <translation>Feldbeschreibung</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="700"/>
        <source>Value</source>
        <translation>Wert</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="700"/>
        <source>Field value</source>
        <translation>Feldwert</translation>
    </message>
</context>
<context>
    <name>Boxvar</name>
    <message>
        <location filename="../prefs.cpp" line="61"/>
        <source>Exit On Close Button</source>
        <translation>Beenden durch Schließen-Schaltfläche</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="79"/>
        <source>Host Name Lookup</source>
        <translation>Nachschlagen des Hostnamens</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="80"/>
        <source>Service Name Lookup</source>
        <translation>Nachschlagen des Dienstnamens</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="86"/>
        <source>Disclosure Triangles</source>
        <translation>Aufdeckungsdreiecke</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="87"/>
        <source>Branch Lines</source>
        <translation>Zweiglinien</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="93"/>
        <source>Auto Save Settings on Exit</source>
        <translation>Einstellungen beim Beenden automatisch speichern</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="94"/>
        <source>Selection: Copy PIDs to Clipboard</source>
        <translation>Auswahl: PIDs in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="96"/>
        <source>Normalize NICE</source>
        <translation>NICE normalisieren</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="97"/>
        <source>Use pmap for Map Names</source>
        <translation>Pmap zur Namensgebung bei der Prozessabbildung verwenden</translation>
    </message>
</context>
<context>
    <name>Cbgroup</name>
    <message>
        <location filename="../prefs.cpp" line="117"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
</context>
<context>
    <name>Command</name>
    <message>
        <location filename="../command.cpp" line="209"/>
        <source>The command:

</source>
        <translation>Der Befehl:

</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="213"/>
        <source>

failed with the error:

</source>
        <translation>

scheiterte mit dem Fehler:

</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="216"/>
        <source>Too many processes</source>
        <translation>Zu viele Prozesse</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="219"/>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="229"/>
        <source>

could not be executed because it was not found,
or you did not have execute permission.</source>
        <translation>

konnte nicht ausgeführt werden, mangels fehlender 
Identifizierbarkeit oder Ausführungsberechtigung.</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="234"/>
        <source>

exited with status </source>
        <translation>

endete mit Status </translation>
    </message>
    <message>
        <location filename="../command.cpp" line="238"/>
        <source>Command Failed</source>
        <translation>Befehl fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>CommandDialog</name>
    <message>
        <location filename="../commanddialog.cpp" line="47"/>
        <source>Edit Commands 0.1 alpha</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="63"/>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="79"/>
        <source>Popup</source>
        <translation>Pop-up</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="84"/>
        <source>Command Line:</source>
        <translation>Befehlszeile:</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="95"/>
        <source>Substitutions:
%p	PID
%c	COMMAND
%C	CMDLINE
%u	USER
%%	%

</source>
        <translation>Substitutionen:
%p	PID
%c	BEFEHL
%C	BEFEHLSZEILE
%u	BENUTZER
%%	%

</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="109"/>
        <source>New...</source>
        <translation>Neu...</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="111"/>
        <location filename="../commanddialog.cpp" line="229"/>
        <source>Add...</source>
        <translation>Hinzufügen...</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="113"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="115"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>ControlBar</name>
    <message>
        <location filename="../misc.cpp" line="925"/>
        <source>Linear</source>
        <translation>Linear</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="928"/>
        <source>Tree</source>
        <translation>Baum</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="949"/>
        <source>All Processes</source>
        <translation>Alle Prozesse</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="950"/>
        <source>Your Processes</source>
        <translation>Ihre Prozesse</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="951"/>
        <source>Non-Root Processes</source>
        <translation>Keine Root-Prozesse</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="952"/>
        <source>Running Processes</source>
        <translation>Laufende Prozesse</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="984"/>
        <source>Pause (Ctrl+Space)</source>
        <translation>Pause (Strg+Leertaste)</translation>
    </message>
</context>
<context>
    <name>Details</name>
    <message>
        <location filename="../details.cpp" line="36"/>
        <source>Process %1 ( %2 ) - details</source>
        <translation>Prozess %1 ( %2 ) - Details</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="45"/>
        <source>Files</source>
        <translation>Dateien</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="54"/>
        <source>Sockets</source>
        <translation>Sockets</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="59"/>
        <source>Memory Maps</source>
        <translation>Memory Maps</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="61"/>
        <source>Environment</source>
        <translation>Umgebung</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="62"/>
        <source>All Fields</source>
        <translation>Alle Felder</translation>
    </message>
</context>
<context>
    <name>Environ</name>
    <message>
        <location filename="../details.cpp" line="609"/>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="609"/>
        <source>Variable name</source>
        <translation>Variablenname</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="610"/>
        <source>Value</source>
        <translation>Wert</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="610"/>
        <source>Variable value</source>
        <translation>Variablenwert</translation>
    </message>
</context>
<context>
    <name>EventDialog</name>
    <message>
        <location filename="../watchdog.ui" line="23"/>
        <source>Watchdog 0.1 alpha</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="117"/>
        <source>Eventcat</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="162"/>
        <source>Select condition</source>
        <translation>Bedingung auswählen</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="170"/>
        <source>labelDescrition</source>
        <translation>Etikettbezeichnung</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="193"/>
        <source>Enable</source>
        <translation>Aktivieren</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="219"/>
        <source>process name</source>
        <translation>Prozessname</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="229"/>
        <source>cpu</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="248"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="280"/>
        <source>include already running process</source>
        <translation>derzeitig laufenden Prozess einbeziehen</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="309"/>
        <source>run command</source>
        <translation>Befehl ausführen</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="342"/>
        <source>show Message</source>
        <translation>zeige Nachricht</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="367"/>
        <source>Help (Not yet. just concept)</source>
        <translation>Hilfe (Existiert noch nicht.)</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="394"/>
        <source>%p : pid
%c : command</source>
        <translation>%p : pid
%c : Befehl</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="425"/>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="432"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="439"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="446"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>ExecWindow</name>
    <message>
        <location filename="../message.ui" line="13"/>
        <source>Qps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../message.ui" line="27"/>
        <source>Ok</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="42"/>
        <source>Qps Watchdog</source>
        <translation>Qps Watchdog</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="97"/>
        <source>%1 exit with code %2</source>
        <translation>%1 beendet mit Rückgabewert %2</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="99"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="105"/>
        <source>%1 [running]</source>
        <translation>%1 [laufend]</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="106"/>
        <source>terminate command</source>
        <translation>Befehl abbrechen</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="115"/>
        <source>Error %1 : [%2] Maybe command not found</source>
        <translation>Fehler %1 : [%2] Der Befehl wurde wahrscheinlich nicht gefunden</translation>
    </message>
</context>
<context>
    <name>FieldSelect</name>
    <message>
        <location filename="../fieldsel.cpp" line="34"/>
        <source>Select Custom Fields </source>
        <translation>Benutzerdefinierte Felder auswählen </translation>
    </message>
    <message>
        <location filename="../fieldsel.cpp" line="68"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>Files</name>
    <message>
        <location filename="../details.cpp" line="525"/>
        <source>Fd</source>
        <translation>Fd</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="525"/>
        <source>File descriptor</source>
        <translation>Dateideskriptor</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="527"/>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="527"/>
        <source>Open mode</source>
        <translation>Offener Modus</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="529"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="529"/>
        <source>File name (if available)</source>
        <translation>Dateiname (falls verfügbar)</translation>
    </message>
</context>
<context>
    <name>IntervalDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="51"/>
        <source>Change Update Period</source>
        <translation>Aktualisierungsintervall ändern</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="57"/>
        <source>New Update Period</source>
        <translation>Aktualisierungsintervall</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="94"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="96"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="130"/>
        <source>No UPDATE</source>
        <translation>Keine AKTUALISIERUNG</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="148"/>
        <source>Invalid value</source>
        <translation>Ungültiger Wert</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <location filename="../listmodel.cpp" line="66"/>
        <source>Event Category</source>
        <translation>Ereigniskategorie</translation>
    </message>
    <message>
        <location filename="../listmodel.cpp" line="68"/>
        <source>Enable</source>
        <translation>Aktivieren</translation>
    </message>
</context>
<context>
    <name>Maps</name>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Address Range</source>
        <translation>Adressbereich</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Mapped addresses (hex) )</source>
        <translation>Gemappte Adressen (hex)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Kbytes mapped (dec)</source>
        <translation>Kbytes gemappt (dez)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>Perm</source>
        <translation>Berechtigung</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>Permission flags</source>
        <translation>Berechtigungskennzeichen</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="399"/>
        <source>Offset</source>
        <translation>Versatz</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="399"/>
        <source>File offset at start of mapping (hex)</source>
        <translation>Dateiversatz bei Beginn des Mappings (hex)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="400"/>
        <source>Device</source>
        <translation>Gerät</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="400"/>
        <source>Major,Minor device numbers (dec)</source>
        <translation>Haupt-,Nebengerätsnummern (dez)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="401"/>
        <source>Inode</source>
        <translation>Inode</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="401"/>
        <source>Inode number (dec)</source>
        <translation>Inode Nummer (dez)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="402"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="402"/>
        <source>File name (if available)</source>
        <translation>Dateiname (falls verfügbar)</translation>
    </message>
</context>
<context>
    <name>PermissionDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="273"/>
        <source>Permission</source>
        <translation>Berechtigung</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="282"/>
        <source>Root password</source>
        <translation>Root-Passwort</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="289"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="292"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../prefs.cpp" line="166"/>
        <source>Preferences</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="173"/>
        <source>Setting</source>
        <translation>Einstellung</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="235"/>
        <source>%CPU divided by</source>
        <translation>Durchschnittliche Prozessorlast dargestellt als</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="242"/>
        <source>Total cpu: %1</source>
        <translation>Quotient aller %1 Prozessorkerne</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="243"/>
        <source>Single cpu: 1</source>
        <translation>Gesamtheit</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="249"/>
        <source>default</source>
        <translation>Vorgabe</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="250"/>
        <source>for developer</source>
        <translation>für Entwicker</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="286"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
</context>
<context>
    <name>Proc</name>
    <message>
        <location filename="../proc.cpp" line="1894"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1894"/>
        <source>Process ID</source>
        <translation>Prozess-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1896"/>
        <source>TGID</source>
        <translation>TGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1896"/>
        <source>Task group ID ( parent of threads )</source>
        <translation>Taskgruppen ID ( Eltern von Threads )</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1898"/>
        <source>PPID</source>
        <translation>PPID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1898"/>
        <source>Parent process ID</source>
        <translation>Elternprozess-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1900"/>
        <source>PGID</source>
        <translation>PGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1900"/>
        <source>Process group ID</source>
        <translation>Prozessgruppen-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1902"/>
        <source>SID</source>
        <translation>SID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1902"/>
        <source>Session ID</source>
        <translation>Sitzungs-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1904"/>
        <source>TTY</source>
        <translation>TTY</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1904"/>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1906"/>
        <source>TPGID</source>
        <translation>TPGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1906"/>
        <source>Process group ID of tty owner</source>
        <translation>Prozessgruppen-ID des tty-Besitzers</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1908"/>
        <source>USER</source>
        <translation>BENUTZER</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1908"/>
        <source>Owner (*=suid root, +=suid a user)</source>
        <translation>Besitzer (*=suid Root, +=suid ein Benutzer)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1910"/>
        <source>GROUP</source>
        <translation>GRUPPE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1910"/>
        <source>Group name (*=sgid other)</source>
        <translation>Gruppenname (*=sgid Weitere)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1912"/>
        <source>UID</source>
        <translation>UID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1912"/>
        <source>Real user ID</source>
        <translation>Tatsächliche Benutzer-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1914"/>
        <source>EUID</source>
        <translation>EUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1914"/>
        <source>Effective user ID</source>
        <translation>Effektive Benutzer-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1916"/>
        <source>SUID</source>
        <translation>SUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1916"/>
        <source>Saved user ID (Posix)</source>
        <translation>Gespeicherte Benutzer-ID (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1918"/>
        <source>FSUID</source>
        <translation>FSUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1918"/>
        <source>File system user ID</source>
        <translation>Dateisystem Benutzer-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1920"/>
        <source>GID</source>
        <translation>GID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1920"/>
        <source>Real group ID</source>
        <translation>Tatsächliche Gruppen-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1922"/>
        <source>EGID</source>
        <translation>EGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1922"/>
        <source>Effective group ID</source>
        <translation>Wirksame Gruppen-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1924"/>
        <source>SGID</source>
        <translation>SGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1924"/>
        <source>Saved group ID (Posix)</source>
        <translation>Gespeicherte Gruppen-ID (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1926"/>
        <source>FSGID</source>
        <translation>FSGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1926"/>
        <source>File system group ID</source>
        <translation>Dateisystem Gruppen-ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1928"/>
        <source>PRI</source>
        <translation>PRI</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1928"/>
        <source>Dynamic priority</source>
        <translation>Dynamische Priorität</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1930"/>
        <source>NICE</source>
        <translation>NICE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1930"/>
        <source>Scheduling favour (higher -&gt; less cpu time)</source>
        <translation>Ressourcenbereitstellung (Höhersetzung verringert Rechenzeit)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1932"/>
        <source>NLWP</source>
        <translation>NLWP</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1932"/>
        <source>Number of tasks(threads) in task group</source>
        <translation>Task-/Threadanzahl in einer Taskgruppe</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1934"/>
        <source>PLCY</source>
        <translation>PLCY</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1934"/>
        <source>Scheduling policy</source>
        <translation>Ausführungsrichtlinien</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1936"/>
        <source>RPRI</source>
        <translation>RPRI</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1936"/>
        <source>Realtime priority (0-99, more is better)</source>
        <translation>Echtzeitpriorität (0-99, höher ist besser)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1938"/>
        <source>TMS</source>
        <translation>TMS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1938"/>
        <source>Time slice in milliseconds</source>
        <translation>Zeitausschnitt in Millisekunden</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1940"/>
        <source>%SAVG</source>
        <translation>%SAVG</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1940"/>
        <source>Percentage average sleep time (-1 -&gt; N/A)</source>
        <translation>Prozentsatz durchschnittlicher Auszeit (-1 -&gt; N/V)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1942"/>
        <source>CPUSET</source>
        <translation>CPUSET</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1942"/>
        <source>Affinity CPU mask (0 -&gt; API not supported)</source>
        <translation>CPU-Affinitätsmaske (0 -&gt; API nicht unterstützt)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1944"/>
        <source>MAJFLT</source>
        <translation>MAJFLT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1944"/>
        <source>Number of major faults (disk access)</source>
        <translation>Anzahl großer Fehler (Datenträgerzugriff)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1946"/>
        <source>MINFLT</source>
        <translation>MINFLT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1946"/>
        <source>Number of minor faults (no disk access)</source>
        <translation>Anzahl kleiner Fehler (kein Datenträgerzugriff)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1949"/>
        <source>VSIZE</source>
        <translation>VSIZE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1949"/>
        <source>Virtual image size of process</source>
        <translation>Virtuelle Abbildgröße des Prozesses</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1951"/>
        <source>RSS</source>
        <translation>RSS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1951"/>
        <source>Resident set size</source>
        <translation>Residente Speicherzuweisung</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1953"/>
        <source>MEM</source>
        <translation>MEM</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1953"/>
        <source>memory usage (RSS-SHARE)</source>
        <translation>Speichernutzung (RSS_SHARE)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1955"/>
        <source>TRS</source>
        <translation>TRS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1955"/>
        <source>Text(code) resident set size</source>
        <translation>Text(code) residente Speicherzuweisung</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1957"/>
        <source>DRS</source>
        <translation>DRS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1957"/>
        <source>Data resident set size(malloc+global variable)</source>
        <translation>Residente Datenspeicherzuweisung (malloc+globale Variable)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1959"/>
        <source>STACK</source>
        <translation>STAPEL</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1959"/>
        <source>Stack size</source>
        <translation>Stapelgröße</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1961"/>
        <source>SHARE</source>
        <translation>SHARE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1961"/>
        <source>Shared memory with other libs</source>
        <translation>Geteilter Speicher mit anderen Bibliotheken</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1963"/>
        <source>SWAP</source>
        <translation>SWAP</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1963"/>
        <source>Kbytes on swap device</source>
        <translation>Kbytes auf Auslagerungsbereich</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1965"/>
        <source>IO_R</source>
        <translation>IO_R</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1965"/>
        <source>io read (file)</source>
        <translation>io lesen (Datei)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1967"/>
        <source>IO_W</source>
        <translation>IO_W</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1967"/>
        <source>io write (file)</source>
        <translation>io schreiben (Datei)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1969"/>
        <source>DT</source>
        <translation>DT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1969"/>
        <source>Number of dirty (non-written) pages</source>
        <translation>Anzahl unreiner (nicht-geschriebener) Seiten</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1971"/>
        <source>STAT</source>
        <translation>STAT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1971"/>
        <source>State of the process </source>
        <translation>Prozessstatus </translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1973"/>
        <source>FLAGS</source>
        <translation>FLAGS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1973"/>
        <source>Process flags (hex)</source>
        <translation>Prozessindikatoren (hex)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1975"/>
        <source>WCHAN</source>
        <translation>WCHAN</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1975"/>
        <source>Kernel function where process is sleeping</source>
        <translation>Kernelfunktion bei ruhenden Prozessen</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1977"/>
        <source>%WCPU</source>
        <translation>%WCPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1977"/>
        <source>Weighted percentage of CPU (30 s average)</source>
        <translation>Durchschnittlich prozentuale CPU-Auslastung innerhalb 30 Sekunden</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1979"/>
        <source>%CPU</source>
        <translation>%CPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1979"/>
        <source>Percentage of CPU used since last update</source>
        <translation>Prozentual verwendete CPU-Ressourcen seit letzter Aktualisierung</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1981"/>
        <source>%MEM</source>
        <translation>%MEM</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1981"/>
        <source>Percentage of memory used (RSS/total mem)</source>
        <translation>Prozentual verwendeter Speicher (RSS/gesamter Speicher)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1983"/>
        <source>START</source>
        <translation>START</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1983"/>
        <source>Time process started</source>
        <translation>Startzeit des Prozesses</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1985"/>
        <source>TIME</source>
        <translation>ZEIT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1985"/>
        <source>Total CPU time used since start</source>
        <translation>Seit dem Start verbrauchte gesamte CPU-Zeit</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1987"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1987"/>
        <source>CPU the process is executing on (SMP system)</source>
        <translation>CPU, auf der der Prozess ausgeführt wird (SMP-System)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1989"/>
        <source>the process name</source>
        <translation>der Prozessname</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1989"/>
        <source>Process Name</source>
        <translation>Prozessname</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1993"/>
        <source>CWD</source>
        <translation>CWD</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1993"/>
        <source>Current working directory</source>
        <translation>Aktuelles Arbeitsverzeichnis</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1994"/>
        <source>ROOT</source>
        <translation>ROOT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1994"/>
        <source>Root directory of process</source>
        <translation>Rootverzeichnis des Prozesses</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1997"/>
        <source>COMMAND_LINE</source>
        <translation>COMMAND_LINE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="1997"/>
        <source>Command line that started the process</source>
        <translation>Befehlszeile, die den Prozess startete</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../qps.cpp" line="2215"/>
        <source>Show</source>
        <translation>Anzeigen</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="2218"/>
        <source>Hide</source>
        <translation>Ausblenden</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="2224"/>
        <source>ScreenShot</source>
        <translation>Bildschirmfoto</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="2229"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
</context>
<context>
    <name>Qps</name>
    <message>
        <location filename="../qps.cpp" line="189"/>
        <source>header_popup</source>
        <translation>Kopfzeile_Popup</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="190"/>
        <source>Remove Field</source>
        <translation>Feld Entfernen</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="191"/>
        <source>Add Field</source>
        <translation>Feld hinzufügen</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="197"/>
        <source>Command</source>
        <translation>Befehl</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="201"/>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="202"/>
        <source>Process</source>
        <translation>Prozess</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="203"/>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="207"/>
        <source>Custom Fields</source>
        <translation>Benutzerdefiniertes</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="209"/>
        <source>Basic Fields </source>
        <translation>Grundlegendes </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="211"/>
        <source>Jobs Fields </source>
        <translation>Aufträge </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="213"/>
        <source>Memory Fields </source>
        <translation>Speicher </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="216"/>
        <source>Scheduling Fields </source>
        <translation>Terminierungen </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="222"/>
        <source>Select Custom Fields...</source>
        <translation>Benutzerdefinierte auswählen...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="236"/>
        <source>Option</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="237"/>
        <source>Update Period...</source>
        <translation>Aktualisierungsperiode...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="246"/>
        <source>Show Status bar</source>
        <translation>Statusleiste anzeigen</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="255"/>
        <source>Preferences...</source>
        <translation>Einstellungen...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="261"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="263"/>
        <location filename="../qps.cpp" line="2291"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="354"/>
        <source>Detail</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="395"/>
        <source>test</source>
        <translation>Test</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="396"/>
        <source>Copied to Clipboard</source>
        <translation>In die Zwischenablage kopiert</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="505"/>
        <source>context popup</source>
        <translation>Kontext Popup</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="506"/>
        <source>Renice...</source>
        <translation>Ressourcenbereitstellung...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="507"/>
        <source>Scheduling...</source>
        <translation>Ausführungsrichtlinien...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="509"/>
        <source>Terminate</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="511"/>
        <source>Hangup</source>
        <translation>Auflegen</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="512"/>
        <source>Kill</source>
        <translation>Schließen erzwingen</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="513"/>
        <source>Stop</source>
        <translation>Anhalten</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="515"/>
        <source>Continue</source>
        <translation>Fortsetzen</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="528"/>
        <source>SIGINT (interrupt)</source>
        <translation>SIGINT (unterbrechen)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="530"/>
        <source>SIGCONT (continue)</source>
        <translation>SIGCONT (fortfahren)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="532"/>
        <source>SIGSTOP (stop)</source>
        <translation>SIGSTOP (anhalten)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="534"/>
        <source>SIGQUIT (quit)</source>
        <translation>SIGQUIT (verlassen)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="536"/>
        <source>SIGILL (illegal instruction)</source>
        <translation>SIGILL (verbotene Anweisung)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="538"/>
        <source>SIGABRT (abort)</source>
        <translation>SIGABRT (abbrechen)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="540"/>
        <source>SIGFPE (floating point exception)</source>
        <translation>SIGFPE (Gleitkomma-Ausnahme)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="542"/>
        <source>SIGSEGV (segmentation violation)</source>
        <translation>SIGSEGV (Segmentierungsverletzung)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="544"/>
        <source>SIGPIPE (broken pipe)</source>
        <translation>SIGPIPE (fehlerhafte Pipe-Verbindung)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="546"/>
        <source>SIGALRM (timer signal)</source>
        <translation>SIGALRM (Timersignal)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="548"/>
        <source>SIGUSR1 (user-defined 1)</source>
        <translation>SIGUSR1 (Benutzerdefiniert 1)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="550"/>
        <source>SIGUSR2 (user-defined 2)</source>
        <translation>SIGUSR2 (Benutzerdefiniert 2)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="552"/>
        <source>SIGCHLD (child death)</source>
        <translation>SIGCHLD (Unterprozessabbruch)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="554"/>
        <source>SIGTSTP (stop from tty)</source>
        <translation>SIGTSTP (Vom TTY anhalten)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="556"/>
        <source>SIGTTIN (tty input)</source>
        <translation>SIGTTIN (TTY Eingabe)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="558"/>
        <source>SIGTTOU (tty output)</source>
        <translation>SIGTTOU (TTY Ausgabe)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="565"/>
        <source>View Details</source>
        <translation>Siehe Einzelheiten</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1181"/>
        <source>WatchDog</source>
        <translation>WatchDog</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1185"/>
        <source>Edit Commands...</source>
        <translation>Befehle bearbeiten...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1210"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1590"/>
        <location filename="../qps.cpp" line="1627"/>
        <location filename="../qps.cpp" line="1634"/>
        <location filename="../qps.cpp" line="1656"/>
        <location filename="../qps.cpp" line="1694"/>
        <location filename="../qps.cpp" line="1773"/>
        <source>Permission denied</source>
        <translation>Berechtigung verweigert</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1591"/>
        <source>You do not have permission to renice the selected processes. Only the process owner and the super-user are allowed to do that.</source>
        <translation>Keine Berechtigung die Ressourcenbereitstellung des ausgewählten Prozesses zu ändern. Dies ist ausschließlich dem Prozesseigentümer und &quot;Super-Usern&quot; vorbehalten.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1628"/>
        <source>You do not have permission to renice process %1 (%2).Only the process owner and the super-user are allowed to do that.</source>
        <translation>Keine Berechtigung die Ressourcenbereitstellung des Prozesses %1 (%2) zu ändern. Dies ist ausschließlich dem Prozesseigentümer und &quot;Super-Usern&quot; vorbehalten.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1635"/>
        <source>Only the super-user may lower the nice value of a process.</source>
        <translation>Ausschließlich &quot;Super-User&quot; sind berechtigt den Wert der Ressourcenbereitstellung zu reduzieren.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1657"/>
        <source>Only the super-user may change the scheduling policy and static priority.</source>
        <translation>Ausschließlich &quot;Super-User&quot; sind berechtigt Ausführungsrichtlinien und statische Priorität zu ändern.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1695"/>
        <source>You do not have permission to change the scheduling and/or priority of process %1 (%2). Only the super-user may do that.</source>
        <translation>Keine Berechtigung Ausführungsrichtlinien und/oder statische Priorität des Prozesses 1% (%2) zu ändern. Dies ist ausschließlich &quot;Super-Usern&quot; vorbehalten.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1774"/>
        <source>You do not have permission to send a signal to process %1 (%2). Only the super-user and the owner of the process may send signals to it.</source>
        <translation>Keine Berechtigung Signal an Prozess 1% (%2) zu senden. Dies ist ausschließlich &quot;Super-Usern&quot; vorbehalten.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="2311"/>
        <source>&lt;h2&gt; Qps %1 - A Visual Process Manager &lt;/h2&gt; %2 using Qt library %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Source: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Bugtracker: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;</source>
        <translation>&lt;h2&gt; Qps %1 - Eine Prozessverwaltung mit grafischer Benutzeroberfläche &lt;/h2&gt; %2 unter Verwendung der Qt Bibliothek %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Source: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Bugtracker: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="2331"/>
        <source>&lt;b&gt;Original Qps by&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Contributors&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</source>
        <translation>&lt;b&gt;Ursprüngliche Entwickelung von Qps&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Beitragende&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="2373"/>
        <source>&lt;H1&gt;QPS Help&lt;/H1&gt;Updated: May 24 2005&lt;BR&gt;&lt;A HREF=&quot;http://kldp.net/projects/qps&quot;&gt;http://kldp.net/projects/qps&lt;/A&gt;&lt;HR&gt;&lt;table style=&quot;text-align: center; width: 100%;&quot; border=&quot;1&quot; cellpadding=&quot;1&quot; cellspacing=&quot;0&quot;&gt;  &lt;tbody&gt;    &lt;tr&gt;      &lt;td style=&quot;vertical-align: top; background-color: rgb(204, 204, 204);&quot;&gt;Quit      &lt;/td&gt;      &lt;td &gt;&amp;nbsp; CTRL + q , CTRL + x      &lt;/td&gt;    &lt;/tr&gt;    &lt;tr&gt;      &lt;td style=&quot;vertical-align: top; background-color: rgb(204, 204, 204);&quot;&gt;Update      &lt;/td&gt;      &lt;td&gt;&amp;nbsp;Space , Enter       &lt;/td&gt;    &lt;/tr&gt;    &lt;tr&gt;&lt;td&gt; process Terminate &lt;/td&gt;  &lt;td&gt; ALT + T , DELETE &lt;/td&gt; &lt;/tr&gt;    &lt;tr&gt;&lt;td&gt; process Kill &lt;/td&gt;  &lt;td&gt; ALT + K  &lt;/td&gt; &lt;/tr&gt;  &lt;/tbody&gt;&lt;/table&gt;</source>
        <translation>&lt;H1&gt;QPS Hilfe&lt;/H1&gt;Aktualisiert: 24.05.2005&lt;BR&gt;&lt;A HREF=&quot;http://kldp.net/projects/qps&quot;&gt;http://kldp.net/projects/qps&lt;/A&gt;&lt;HR&gt;&lt;table style=&quot;text-align: center; width: 100%;&quot; border=&quot;1&quot; cellpadding=&quot;1&quot; cellspacing=&quot;0&quot;&gt;  &lt;tbody&gt;    &lt;tr&gt;      &lt;td style=&quot;vertical-align: top; background-color: rgb(204, 204, 204);&quot;&gt;Quit      &lt;/td&gt;      &lt;td &gt;&amp;nbsp; CTRL + q , CTRL + x      &lt;/td&gt;    &lt;/tr&gt;    &lt;tr&gt;      &lt;td style=&quot;vertical-align: top; background-color: rgb(204, 204, 204);&quot;&gt;Update      &lt;/td&gt;      &lt;td&gt;&amp;nbsp;Space , Enter       &lt;/td&gt;    &lt;/tr&gt;    &lt;tr&gt;&lt;td&gt; process Terminate &lt;/td&gt;  &lt;td&gt; ALT + T , DELETE &lt;/td&gt; &lt;/tr&gt;    &lt;tr&gt;&lt;td&gt; process Kill &lt;/td&gt;  &lt;td&gt; ALT + K  &lt;/td&gt; &lt;/tr&gt;  &lt;/tbody&gt;&lt;/table&gt;</translation>
    </message>
</context>
<context>
    <name>SchedDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="301"/>
        <source>Change scheduling</source>
        <translation>Ausführungsrichtlinien ändern</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="305"/>
        <source>Scheduling Policy</source>
        <translation>Ausführungsrichtlinien</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="307"/>
        <source>SCHED_OTHER (time-sharing)</source>
        <translation>SCHED_OTHER (Rechenzeitaufteilung)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="308"/>
        <source>SCHED_FIFO (real-time)</source>
        <translation>SCHED_FIFO (Echtzeit)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="309"/>
        <source>SCHED_RR (real-time)</source>
        <translation>SCHED_RR (Echtzeit)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="323"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="325"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="355"/>
        <source>Priority (1-99):</source>
        <translation>Priorität (1-99):</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="388"/>
        <source>Invalid Input</source>
        <translation>Ungültige Eingabe</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="389"/>
        <source>The priority must be in the range 1..99</source>
        <translation>Die Priorität muss im Bereich von 1..99 liegen</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <location filename="../screenshot.cpp" line="294"/>
        <source>/untitled.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="299"/>
        <source>Save As</source>
        <translation>Speichern unter</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="300"/>
        <source>%1 Files (*.%2);;All Files (*)</source>
        <translation>%1 Dateien (*.%2);;Alle Dateien (*)</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="327"/>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="330"/>
        <source> s</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="335"/>
        <source>Screenshot Delay:</source>
        <translation>Bildschirmfotoverzögerung:</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="337"/>
        <source>Hide This Window</source>
        <translation>Verstecke Dieses Fenster</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="349"/>
        <source>New Screenshot</source>
        <translation>Neues Bildschirmfoto</translation>
    </message>
    <message>
        <location filename="../screenshot.cpp" line="350"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
</context>
<context>
    <name>SearchBox</name>
    <message>
        <location filename="../misc.cpp" line="806"/>
        <source>PID,COMMAND,USER...</source>
        <translation>PID,BEFEHL,BENUTZER...</translation>
    </message>
</context>
<context>
    <name>SliderDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="188"/>
        <source>Renice Process</source>
        <translation>Ressourcenbereitstellungsprozess</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="194"/>
        <source>New nice value:</source>
        <translation>Neuer Ressourcenbereitstellungswert:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="234"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="238"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Sockets</name>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Fd</source>
        <translation>Fd</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>File descriptor</source>
        <translation>Dateideskriptor</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <source>Proto</source>
        <translation>Proto</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <source>Protocol (TCP or UDP)</source>
        <translation>Protokoll (TCP oder UDP)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Recv-Q</source>
        <translation>Recv-Q</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Bytes in receive queue</source>
        <translation>Bytes innerhalb Empfangswarteschlange</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="154"/>
        <source>Send-Q</source>
        <translation>Send-Q</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="154"/>
        <source>Bytes in send queue</source>
        <translation>Bytes innerhalb Sendewarteschlange</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>Local Addr</source>
        <translation>Local Addr</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>Local IP address</source>
        <translation>Lokale IP-Adresse</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="156"/>
        <location filename="../details.cpp" line="158"/>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="156"/>
        <source>Local port</source>
        <translation>Lokaler Port</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="157"/>
        <source>Remote Addr</source>
        <translation>Rechnerferne Addresse</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="157"/>
        <source>Remote IP address</source>
        <translation>Rechnerferne IP-Adresse</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="158"/>
        <source>Remote port</source>
        <translation>Rechnerferner Anschluss</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="159"/>
        <source>State</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="159"/>
        <source>Connection state</source>
        <translation>Verbindungsstatus</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../misc.cpp" line="895"/>
        <source>Process count: %1</source>
        <translation>Prozessanzahl: %1</translation>
    </message>
</context>
<context>
    <name>TBloon</name>
    <message>
        <location filename="../misc.cpp" line="347"/>
        <source> This is unstable Alpha feature
 You maybe see a SEGFAULT...</source>
        <translation> Dies ist eine instabile Alphafunktion.
 SEGFAULTs sind möglich.</translation>
    </message>
</context>
<context>
    <name>TFrame</name>
    <message>
        <location filename="../misc.cpp" line="426"/>
        <source>this is Tframe widget</source>
        <translation>Dies ist ein Tframe-Steuerelement</translation>
    </message>
</context>
<context>
    <name>UFrame</name>
    <message>
        <location filename="../misc.cpp" line="615"/>
        <source>title</source>
        <translation>Titel</translation>
    </message>
</context>
<context>
    <name>WatchdogDialog</name>
    <message>
        <location filename="../watchdogdialog.cpp" line="193"/>
        <source>if process start</source>
        <translation>wenn der Prozess startet</translation>
    </message>
    <message>
        <location filename="../watchdogdialog.cpp" line="194"/>
        <source>if process finish</source>
        <translation>wenn der Prozess abgeschlossen ist</translation>
    </message>
    <message>
        <location filename="../watchdogdialog.cpp" line="217"/>
        <source>select condition</source>
        <translation>Bedingung auswählen</translation>
    </message>
</context>
</TS>
